dom-query-helpers
=================

A super tiny DOM query helper library.

[![Build Status](https://travis-ci.org/jsor/dom-query-helpers.svg?branch=master)](https://travis-ci.org/jsor/dom-query-helpers)

Installation
------------

```bash
npm install dom-query-helpers
```

**Note**: This library is written as ES2015 code and published as such to 
[npm](https://www.npmjs.com/package/dom-query-helpers).
That means, code from `dom-query-helpers` must *not* be excluded from
transpilation.

If you're using webpack and babel, that could look like:

```javascript
{
    module: {
        rules: [
            {
                test: /\.js$/,
                exclude: /node_modules\/(?!dom-query-helpers)/,
                loader: 'babel-loader'
            }
        ]
    }
}
```

Usage
-----

```javascript
import { closest, matches, query } from 'dom-query-helpers';
```

### closest()

```
closest(element: Element, selector: string): Element
```

Returns the closest ancestor of the `element` (or the `element` itself) which
matches the specified `selector`. 

If there isn't such an ancestor, it returns `null`.

#### Example

```javascript
const closestParagraph = closest(element, 'p');
```

### matches()

```
matches(element: Element, selector: string): boolean
```

Returns `true` if the `element` would be selected by the specified `selector`, 
`false` otherwise.

#### Example

```javascript
const isParagraph = matches(element, 'p');
```

### query()

```
query(selector: string[, element: Element]): array
```

Returns an `array` of elements matching the specified `selector` which are
descendants of the `document` or the `element` specified as optional second 
argument.

#### Example

```javascript
const paragraphs = query('p');

const spansInsideFirstParagraph = query('spans', paragraphs[0]);
```

License
-------

Copyright (c) 2018 Jan Sorgalla.
Released under the [MIT](LICENSE) license.
